#!/usr/bin/bash
DIR="$( cd "$( dirname "$0" )" && pwd )"
PRODUCT_NAME='DiskEditor'
PREFIX="/opt/lsoft"
INSTALL_DIR="$PREFIX/$PRODUCT_NAME"
OLD_INSTALL_DIR='/opt'
INSTALLER_VER="1.1"

COPY_PATHS=
COPY_PATHS+=' lib'
COPY_PATHS+=' plugins'
#COPY_PATHS+=' translations'
#COPY_PATHS+=' qt.conf'
COPY_PATHS+=" $PRODUCT_NAME"
COPY_PATHS+=" $PRODUCT_NAME.sh"
COPY_PATHS+=" $PRODUCT_NAME.pdf"
COPY_PATHS+=" license.txt"
#COPY_PATHS+=" disk-bay-layout.dbl"

INSTALLED=

function copy_and_log {
    sudo cp -a "$1" "$2"
    INSTALLED+="$2/$(basename "$1") "
    echo "Installed $1 to $2"
}

for i in $COPY_PATHS; do
    if [ ! -e "$DIR/$i" ]; then #Check for file exists
        echo "Error: $DIR/$i not found"
        exit 1
    fi
done

if [ -e $OLD_INSTALL_DIR/$PRODUCT_NAME ]; then  # Clean old dir if exists
    sudo rm -R $OLD_INSTALL_DIR/$PRODUCT_NAME
fi

if [ -e $INSTALL_DIR ]; then  # Clean if exists
    sudo rm -R $INSTALL_DIR
fi

sudo mkdir -p $INSTALL_DIR

#Fix permissions
sudo chmod 755 /opt
sudo chmod -R 755 $PREFIX

for i in $COPY_PATHS; do
    copy_and_log "$DIR/$i" $INSTALL_DIR
done

sudo bash -c "cat <<EOF > $DIR/$PRODUCT_NAME.desktop
[Desktop Entry]
Exec=$INSTALL_DIR/$PRODUCT_NAME.sh
GenericName=Active@ Disk Editor
Icon=DiskEditor
Name=Active@ Disk Editor
StartupNotify=true
Terminal=false
Type=Application
X-KDE-SubstituteUID=false
Categories=Application;Utility;
EOF"

sudo bash -c "cat <<EOF > $INSTALL_DIR/qt.conf
[Paths]
Prefix = $INSTALL_DIR
EOF"

sudo bash -c "cat <<EOF > $INSTALL_DIR/temp.sh
#!/bin/bash
$INSTALL_DIR/$PRODUCT_NAME \"\\\$@\"
EOF"

sudo bash -c "cat <<EOF > $INSTALL_DIR/uninstall.sh
#!/bin/bash
sudo rm -R $INSTALLED
EOF"

copy_and_log "$DIR/$PRODUCT_NAME.png" /usr/share/pixmaps
copy_and_log "$DIR/$PRODUCT_NAME.desktop" /usr/share/applications

sudo chmod 755 /usr/share/applications/$PRODUCT_NAME.desktop
sudo chmod 644 /usr/share/pixmaps/$PRODUCT_NAME.png
sudo chmod 755 $INSTALL_DIR/$PRODUCT_NAME
sudo chmod 755 $INSTALL_DIR/$PRODUCT_NAME.sh
sudo chmod 644 $INSTALL_DIR/qt.conf
sudo chmod 755 $INSTALL_DIR/temp.sh
sudo chmod 755 $INSTALL_DIR/uninstall.sh

echo "Installation completed successfully [Installer version: $INSTALLER_VER]"

